---
name: Feature Request
about: Suggest an idea for this project

---

## Get Support
To get help or technical support, see [Get Support](https://pylonsproject.org/community-support.html).

## Feature Request

Please [search the issue tracker](https://github.com/Pylons/pyramid/issues) for similar issues before submitting a new issue.

**Is your feature request related to an issue? Please describe.**
A clear and concise description of the issue. Example: "I'm always frustrated when [...]".

**Describe the solution you'd like**
A clear and concise description of what you want to happen.

**Describe alternatives you've considered**
A clear and concise description of any alternative solutions or features you've considered.

**Additional context**
Add any other context or screenshots about the feature request here.
